@@ -244,7 +244,9 @@ END
 ########################################
 END
    print $show;
-   $handle->{_cmd_handle}->print('sudo cpan Catalyst::Devel');
+   $handle->{_cmd_handle}->print( #'sudo cpan Catalyst::Devel');
+      'sudo perl -MCPAN -e \'CPAN::Shell->force('.
+      '"install","Regexp::Assemble")\'');
    $prompt=substr($handle->{_cmd_handle}->prompt(),1,-1);
    while (1) {
       my $output.=Net::FullAuto::FA_Core::fetch($handle);
