@@ -181,7 +181,7 @@ my $standup_kali_linux=sub {
       my $region = "wget -qO- http://169.254.169.254/latest/".
                    "dynamic/instance-identity/document|grep region";
       $region=`$region`;
-      $region=~s/^.*: ["](.*)["]\s*$/$1/;
+      $region=~s/^.*: ["](.*)["],\s*$/$1/s;
       my ($hash,$output,$error)=('','','');
       ($hash,$output,$error)=run_aws_cmd(
          "aws ec2 describe-images --owners 099720109477 ".
